@@ -1,7 +1,7 @@
 // synthv1.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -27,9 +27,11 @@
 #include "synthv1_list.h"
 
 #include "synthv1_fx.h"
-
 #include "synthv1_reverb.h"
 
+#include "synthv1_config.h"
+#include "synthv1_programs.h"
+
 
 #ifdef CONFIG_DEBUG_0
 #include <stdio.h>
@@ -747,7 +749,7 @@ class synthv1_impl
 {
 public:
 
-	synthv1_impl(uint16_t iChannels, uint32_t iSampleRate);
+	synthv1_impl(synthv1 *pSynth, uint16_t iChannels, uint32_t iSampleRate);
 
 	~synthv1_impl();
 
@@ -758,7 +760,12 @@ public:
 	uint32_t sampleRate() const;
 
 	void setParamPort(synthv1::ParamIndex index, float *pfParam = 0);
-	float *paramPort(synthv1::ParamIndex index);
+	float *paramPort(synthv1::ParamIndex index) const;
+
+	void setParamValue(synthv1::ParamIndex index, float fValue);
+	float paramValue(synthv1::ParamIndex index) const;
+
+	synthv1_programs *programs();
 
 	void process_midi(uint8_t *data, uint32_t size);
 	void process(float **ins, float **outs, uint32_t nframes);
@@ -809,6 +816,9 @@ protected:
 
 private:
 
+	synthv1_config   m_config;
+	synthv1_programs m_programs;
+
 	uint16_t m_iChannels;
 	uint32_t m_iSampleRate;
 
@@ -880,7 +890,9 @@ synthv1_voice::synthv1_voice ( synthv1_impl *pImpl ) :
 
 // engine constructor
 
-synthv1_impl::synthv1_impl ( uint16_t iChannels, uint32_t iSampleRate )
+synthv1_impl::synthv1_impl (
+	synthv1 *pSynth, uint16_t iChannels, uint32_t iSampleRate )
+	: m_programs(pSynth)
 {
 	// max env. stage length (default)
 	m_dco1.envtime0 = m_dco2.envtime0 = 0.0001f * MAX_ENV_MSECS;
@@ -918,6 +930,9 @@ synthv1_impl::synthv1_impl ( uint16_t iChannels, uint32_t iSampleRate )
 	m_del.bpmsync0 = 0.0f;
 	m_del.bpm0 = 0;
 
+	// load programs database...
+	m_config.loadPrograms(&m_programs);
+
 	// number of channels
 	setChannels(iChannels);
 
@@ -938,6 +953,12 @@ synthv1_impl::synthv1_impl ( uint16_t iChannels, uint32_t iSampleRate )
 
 synthv1_impl::~synthv1_impl (void)
 {
+#if 0
+	// DO NOT save programs database here:
+	// prevent multi-instance clash...
+	m_config.savePrograms(&m_programs);
+#endif
+
 	// deallocate voice pool.
 	for (int i = 0; i < MAX_VOICES; ++i)
 		delete m_voices[i];
@@ -1200,7 +1221,7 @@ void synthv1_impl::setParamPort ( synthv1::ParamIndex index, float *pfParam )
 }
 
 
-float *synthv1_impl::paramPort ( synthv1::ParamIndex index )
+float *synthv1_impl::paramPort ( synthv1::ParamIndex index ) const
 {
 	float *pfParam= 0;
 
@@ -1337,6 +1358,21 @@ float *synthv1_impl::paramPort ( synthv1::ParamIndex index )
 }
 
 
+void synthv1_impl::setParamValue ( synthv1::ParamIndex index, float fValue )
+{
+	float *pfParamPort = paramPort(index);
+	if (pfParamPort)
+		*pfParamPort = fValue;
+}
+
+
+float synthv1_impl::paramValue ( synthv1::ParamIndex index ) const
+{
+	float *pfParamPort = paramPort(index);
+	return (pfParamPort ? *pfParamPort : 0.0f);
+}
+
+
 // handle midi input
 
 void synthv1_impl::process_midi ( uint8_t *data, uint32_t size )
@@ -1360,6 +1396,10 @@ void synthv1_impl::process_midi ( uint8_t *data, uint32_t size )
 	const int status = (data[0] & 0xf0);
 	const int key    = (data[1] & 0x7f);
 
+	// program change
+	if (status == 0xc0)
+		m_programs.prog_change(key);
+	else
 	if (status == 0xd0) {
 		// channel aftertouch
 		const float pre = float(key) / 127.0f;
@@ -1577,6 +1617,10 @@ void synthv1_impl::process_midi ( uint8_t *data, uint32_t size )
 	// control change
 	else if (status == 0xb0) {
 		switch (key) {
+		case 0x00:
+			// bank-select MSB (cc#0)
+			m_programs.bank_select_msb(value);
+			break;
 		case 0x01: {
 			// modulation wheel (cc#1)
 			const float mod = float(value) / 127.0f;
@@ -1598,6 +1642,10 @@ void synthv1_impl::process_midi ( uint8_t *data, uint32_t size )
 			if (on2) m_ctl2.panning = pan;
 			break;
 		}
+		case 0x20:
+			// bank-select LSB (cc#32)
+			m_programs.bank_select_lsb(value);
+			break;
 		case 0x40:
 			// sustain/damper pedal (cc#64)
 			if (on1) {
@@ -1785,6 +1833,14 @@ void synthv1_impl::allSoundOff (void)
 }
 
 
+// programs accessor
+
+synthv1_programs *synthv1_impl::programs (void)
+{
+	return &m_programs;
+}
+
+
 // all reset clear
 
 void synthv1_impl::reset (void)
@@ -2126,13 +2182,14 @@ void synthv1_impl::process ( float **ins, float **outs, uint32_t nframes )
 }
 
 
+
 //-------------------------------------------------------------------------
 // synthv1 - decl.
 //
 
 synthv1::synthv1 ( uint16_t iChannels, uint32_t iSampleRate )
 {
-	m_pImpl = new synthv1_impl(iChannels, iSampleRate);
+	m_pImpl = new synthv1_impl(this, iChannels, iSampleRate);
 }
 
 
@@ -2177,6 +2234,17 @@ float *synthv1::paramPort ( ParamIndex index ) const
 }
 
 
+void synthv1::setParamValue ( ParamIndex index, float fValue )
+{
+	m_pImpl->setParamValue(index, fValue);
+}
+
+float synthv1::paramValue ( ParamIndex index ) const
+{
+	return m_pImpl->paramValue(index);
+}
+
+
 void synthv1::process_midi ( uint8_t *data, uint32_t size )
 {
 #ifdef CONFIG_DEBUG_0
@@ -2196,6 +2264,14 @@ void synthv1::process ( float **ins, float **outs, uint32_t nframes )
 }
 
 
+// programs accessor
+
+synthv1_programs *synthv1::programs (void) const
+{
+	return m_pImpl->programs();
+}
+
+
 // all reset clear
 
 void synthv1::reset (void)
