@@ -1,7 +1,7 @@
 // synthv1.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
 
 // forward declarations
 class synthv1_impl;
+class synthv1_programs;
 
 
 //-------------------------------------------------------------------------
@@ -186,9 +187,12 @@ public:
 	void setParamPort(ParamIndex index, float *pfParam);
 	float *paramPort(ParamIndex index) const;
 
-	void reset();
+	synthv1_programs *programs() const;
 
-protected:
+	void setParamValue(ParamIndex index, float fValue);
+	float paramValue(ParamIndex index) const;
+
+	void reset();
 
 	void process_midi(uint8_t *data, uint32_t size);
 	void process(float **ins, float **outs, uint32_t nframes);
