@@ -1,7 +1,7 @@
 // synthv1_jack.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -19,9 +19,8 @@
 
 *****************************************************************************/
 
-#include "synthv1_config.h"
-
 #include "synthv1_jack.h"
+#include "synthv1_config.h"
 #include "synthv1_param.h"
 
 #include <jack/midiport.h>
@@ -149,7 +148,7 @@ synthv1_jack::synthv1_jack (void) : synthv1(2)
 
 	m_ins = m_outs = NULL;
 
-	::memset(m_params, 0, NUM_PARAMS * sizeof(float));
+	::memset(m_params, 0, synthv1::NUM_PARAMS * sizeof(float));
 
 #ifdef CONFIG_JACK_MIDI
 	m_midi_in = NULL;
@@ -188,7 +187,7 @@ int synthv1_jack::process ( jack_nframes_t nframes )
 	if (!m_activated)
 		return 0;
 
-	const uint16_t nchannels = channels();
+	const uint16_t nchannels = synthv1::channels();
 	float *ins[nchannels], *outs[nchannels];
 	for (uint16_t k = 0; k < nchannels; ++k) {
 		ins[k]  = static_cast<float *> (
@@ -197,16 +196,16 @@ int synthv1_jack::process ( jack_nframes_t nframes )
 			::jack_port_get_buffer(m_audio_outs[k], nframes));
 	}
 
-	const float *bpmsync = paramPort(synthv1::DEL1_BPMSYNC);
-	if (bpmsync && *bpmsync > 0.0f) {
-		float *bpmhost = paramPort(synthv1::DEL1_BPMHOST);
-		if (bpmhost) {
+	const float bpm_sync = paramValue(synthv1::DEL1_BPMSYNC);
+	if (bpm_sync > 0.0f) {
+		const float bpm_host = paramValue(synthv1::DEL1_BPMHOST);
+		if (bpm_host > 0.0f) {
 			jack_position_t pos;
 			jack_transport_query(m_client, &pos);
 			if (pos.valid & JackPositionBBT) {
 				const float bpm = float(pos.beats_per_minute);
-				if (::fabs(*bpmhost - bpm) > 0.01f)
-					*bpmhost = bpm;
+				if (::fabs(bpm_host - bpm) > 0.01f)
+					setParamValue(synthv1::DEL1_BPMHOST, bpm);
 			}
 		}
 	}
@@ -289,7 +288,7 @@ void synthv1_jack::open ( const char *client_id )
 //	synthv1::reset();
 
 	// register audio ports & buffers
-	uint16_t nchannels = channels();
+	uint16_t nchannels = synthv1::channels();
 
 	m_audio_ins  = new jack_port_t * [nchannels];
 	m_audio_outs = new jack_port_t * [nchannels];
@@ -411,7 +410,7 @@ void synthv1_jack::close (void)
 #endif
 
 	// unregister audio ports
-	uint16_t nchannels = channels();
+	const uint16_t nchannels = synthv1::channels();
 
 	for (uint16_t k = 0; k < nchannels; ++k) {
 		if (m_audio_outs && m_audio_outs[k]) {
@@ -593,7 +592,7 @@ void synthv1_jack::sessionEvent ( void *pvSessionArg )
 
 
 //-------------------------------------------------------------------------
-// synthv1_application -- Singleton application instance.
+// synthv1_jack_application -- Singleton application instance.
 //
 
 #include "synthv1widget_jack.h"
@@ -607,7 +606,7 @@ void synthv1_jack::sessionEvent ( void *pvSessionArg )
 
 
 // Constructor.
-synthv1_application::synthv1_application ( int& argc, char **argv )
+synthv1_jack_application::synthv1_jack_application ( int& argc, char **argv )
 	: QObject(NULL), m_pApp(NULL), m_bGui(true),
 		m_pSynth(NULL), m_pWidget(NULL)
 	  #ifdef CONFIG_NSM
@@ -634,7 +633,7 @@ synthv1_application::synthv1_application ( int& argc, char **argv )
 
 
 // Destructor.
-synthv1_application::~synthv1_application (void)
+synthv1_jack_application::~synthv1_jack_application (void)
 {
 #ifdef CONFIG_NSM
 	if (m_pNsmClient) delete m_pNsmClient;
@@ -646,7 +645,7 @@ synthv1_application::~synthv1_application (void)
 
 
 // Argument parser method.
-bool synthv1_application::parse_args (void)
+bool synthv1_jack_application::parse_args (void)
 {
 	QTextStream out(stderr);
 
@@ -678,7 +677,7 @@ bool synthv1_application::parse_args (void)
 
 
 // Startup methods.
-bool synthv1_application::setup (void)
+bool synthv1_jack_application::setup (void)
 {
 	if (m_pApp == NULL)
 		return false;
@@ -734,7 +733,7 @@ bool synthv1_application::setup (void)
 
 
 // Facade method.
-int synthv1_application::exec (void)
+int synthv1_jack_application::exec (void)
 {
 	return (setup() ? m_pApp->exec() : 1);
 }
@@ -742,7 +741,7 @@ int synthv1_application::exec (void)
 
 #ifdef CONFIG_NSM
 
-void synthv1_application::openSession (void)
+void synthv1_jack_application::openSession (void)
 {
 	if (m_pSynth == NULL)
 		return;
@@ -788,7 +787,7 @@ void synthv1_application::openSession (void)
 		m_pNsmClient->visible(m_pWidget->isVisible());
 }
 
-void synthv1_application::saveSession (void)
+void synthv1_jack_application::saveSession (void)
 {
 	if (m_pSynth == NULL)
 		return;
@@ -815,7 +814,7 @@ void synthv1_application::saveSession (void)
 }
 
 
-void synthv1_application::showSession (void)
+void synthv1_jack_application::showSession (void)
 {
 	if (m_pNsmClient == NULL)
 		return;
@@ -834,7 +833,7 @@ void synthv1_application::showSession (void)
 	}
 }
 
-void synthv1_application::hideSession (void)
+void synthv1_jack_application::hideSession (void)
 {
 	if (m_pNsmClient == NULL)
 		return;
@@ -861,7 +860,7 @@ int main ( int argc, char *argv[] )
 {
 	Q_INIT_RESOURCE(synthv1);
 
-	synthv1_application app(argc, argv);
+	synthv1_jack_application app(argc, argv);
 
 	return app.exec();
 }
