@@ -1,7 +1,7 @@
 // synthv1_lv2.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -62,7 +62,7 @@ synthv1_lv2::synthv1_lv2 (
 		}
 	}
 
-	const uint16_t nchannels = channels();
+	const uint16_t nchannels = synthv1::channels();
 	m_ins  = new float * [nchannels];
 	m_outs = new float * [nchannels];
 	for (uint16_t k = 0; k < nchannels; ++k)
@@ -96,7 +96,7 @@ void synthv1_lv2::connect_port ( uint32_t port, void *data )
 		m_outs[1] = (float *) data;
 		break;
 	default:
-		setParamPort(ParamIndex(port - ParamBase), (float *) data);
+		synthv1::setParamPort(synthv1::ParamIndex(port - ParamBase), (float *) data);
 		break;
 	}
 }
@@ -104,7 +104,7 @@ void synthv1_lv2::connect_port ( uint32_t port, void *data )
 
 void synthv1_lv2::run ( uint32_t nframes )
 {
-	const uint16_t nchannels = channels();
+	const uint16_t nchannels = synthv1::channels();
 	float *ins[nchannels], *outs[nchannels];
 	for (uint16_t k = 0; k < nchannels; ++k) {
 		ins[k]  = m_ins[k];
@@ -121,14 +121,14 @@ void synthv1_lv2::run ( uint32_t nframes )
 				uint8_t *data = (uint8_t *) LV2_ATOM_BODY(&event->body);
 				const uint32_t nread = event->time.frames - ndelta;
 				if (nread > 0) {
-					process(ins, outs, nread);
+					synthv1::process(ins, outs, nread);
 					for (uint16_t k = 0; k < nchannels; ++k) {
 						ins[k]  += nread;
 						outs[k] += nread;
 					}
 				}
 				ndelta = event->time.frames;
-				process_midi(data, event->body.size);
+				synthv1::process_midi(data, event->body.size);
 			}
 			else
 			if (event->body.type == m_urids.atom_Blank ||
@@ -140,13 +140,13 @@ void synthv1_lv2::run ( uint32_t nframes )
 					lv2_atom_object_get(object,
 						m_urids.time_beatsPerMinute, &atom, NULL);
 					if (atom && atom->type == m_urids.atom_Float) {
-						const float *bpmsync = paramPort(synthv1::DEL1_BPMSYNC);
-						if (bpmsync && *bpmsync > 0.0f) {
-							float *bpmhost = paramPort(synthv1::DEL1_BPMHOST);
-							if (bpmhost) {
+						const float bpm_sync = synthv1::paramValue(synthv1::DEL1_BPMSYNC);
+						if (bpm_sync > 0.0f) {
+							const float bpm_host = synthv1::paramValue(synthv1::DEL1_BPMHOST);
+							if (bpm_host > 0.0f) {
 								const float bpm	= ((LV2_Atom_Float *) atom)->body;
-								if (::fabs(*bpmhost - bpm) > 0.01f)
-									*bpmhost = bpm;
+								if (::fabs(bpm_host - bpm) > 0.01f)
+									synthv1::setParamValue(synthv1::DEL1_BPMHOST, bpm);
 							}
 						}
 					}
@@ -156,22 +156,60 @@ void synthv1_lv2::run ( uint32_t nframes )
 	//	m_atom_sequence = NULL;
 	}
 
-	process(ins, outs, nframes - ndelta);
+	synthv1::process(ins, outs, nframes - ndelta);
 }
 
 
 void synthv1_lv2::activate (void)
 {
-	reset();
+	synthv1::reset();
 }
 
 
 void synthv1_lv2::deactivate (void)
 {
-	reset();
+	synthv1::reset();
 }
 
 
+#ifdef CONFIG_LV2_PROGRAMS
+
+#include "synthv1_programs.h"
+
+const LV2_Program_Descriptor *synthv1_lv2::get_program ( uint32_t index )
+{
+	synthv1_programs *pPrograms = synthv1::programs();
+	const synthv1_programs::Banks& banks = pPrograms->banks();
+	synthv1_programs::Banks::ConstIterator bank_iter = banks.constBegin();
+	const synthv1_programs::Banks::ConstIterator& bank_end = banks.constEnd();
+	for (uint32_t i = 0; bank_iter != bank_end; ++bank_iter) {
+		synthv1_programs::Bank *pBank = bank_iter.value();
+		const synthv1_programs::Progs& progs = pBank->progs();
+		synthv1_programs::Progs::ConstIterator prog_iter = progs.constBegin();
+		const synthv1_programs::Progs::ConstIterator& prog_end = progs.constEnd();
+		for ( ; prog_iter != prog_end; ++prog_iter, ++i) {
+			synthv1_programs::Prog *pProg = prog_iter.value();
+			if (i >= index) {
+				m_aProgramName = pProg->name().toUtf8();
+				m_program.bank = pBank->id();
+				m_program.program = pProg->id();
+				m_program.name = m_aProgramName.constData();
+				return &m_program;
+			}
+		}
+	}
+
+	return NULL;
+}
+
+void synthv1_lv2::select_program ( uint32_t bank, uint32_t program )
+{
+	synthv1::programs()->select_program(bank, program);
+}
+
+#endif	// CONFIG_LV2_PROGRAMS
+
+
 //-------------------------------------------------------------------------
 // synthv1_lv2 - LV2 desc.
 //
@@ -225,8 +263,41 @@ static void synthv1_lv2_cleanup ( LV2_Handle instance )
 }
 
 
-static const void *synthv1_lv2_extension_data ( const char * )
+#ifdef CONFIG_LV2_PROGRAMS
+
+static const LV2_Program_Descriptor *synthv1_lv2_programs_get_program (
+	LV2_Handle instance, uint32_t index )
 {
+	synthv1_lv2 *pPlugin = static_cast<synthv1_lv2 *> (instance);
+	if (pPlugin)
+		return pPlugin->get_program(index);
+	else
+		return NULL;
+}
+
+static void synthv1_lv2_programs_select_program (
+	LV2_Handle instance, uint32_t bank, uint32_t program )
+{
+	synthv1_lv2 *pPlugin = static_cast<synthv1_lv2 *> (instance);
+	if (pPlugin)
+		pPlugin->select_program(bank, program);
+}
+
+static const LV2_Programs_Interface synthv1_lv2_programs_interface =
+{
+	synthv1_lv2_programs_get_program,
+	synthv1_lv2_programs_select_program,
+};
+
+#endif	// CONFIG_LV2_PROGRAMS
+
+static const void *synthv1_lv2_extension_data ( const char *uri )
+{
+#ifdef CONFIG_LV2_PROGRAMS
+	if (::strcmp(uri, LV2_PROGRAMS__Interface) == 0)
+		return (void *) &synthv1_lv2_programs_interface;
+	else
+#endif
     return NULL;
 }
 
