@@ -1,7 +1,7 @@
 // synthv1_param.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -19,8 +19,8 @@
 
 *****************************************************************************/
 
-#include "synthv1_config.h"
 #include "synthv1_param.h"
+#include "synthv1_config.h"
 
 #include <QHash>
 
@@ -190,7 +190,21 @@ void synthv1_param::loadPreset ( synthv1 *pSynth, const QString& sFilename )
 	if (pSynth == NULL)
 		return;
 
-	QFile file(sFilename);
+	QFileInfo fi(sFilename);
+	if (!fi.exists()) {
+		synthv1_config *pConfig = synthv1_config::getInstance();
+		if (pConfig) {
+			const QString& sPresetFile
+				= pConfig->presetFile(sFilename);
+			if (sPresetFile.isEmpty())
+				return;
+			fi.setFile(sPresetFile);
+			if (!fi.exists())
+				return;
+		}
+	}
+
+	QFile file(fi.filePath());
 	if (!file.open(QIODevice::ReadOnly))
 		return;
 
@@ -202,8 +216,6 @@ void synthv1_param::loadPreset ( synthv1 *pSynth, const QString& sFilename )
 		}
 	}
 
-	const QFileInfo fi(sFilename);
-
 	QDomDocument doc(SYNTHV1_TITLE);
 	if (doc.setContent(&file)) {
 		QDomElement ePreset = doc.documentElement();
@@ -231,14 +243,12 @@ void synthv1_param::loadPreset ( synthv1 *pSynth, const QString& sFilename )
 									continue;
 								index = s_hash.value(sName);
 							}
-							float fParamValue = eParam.text().toFloat();
+							float fValue = eParam.text().toFloat();
 						#if 1//--legacy support < 0.3.0.4
-							if (index == synthv1::DEL1_BPM && fParamValue < 3.6f)
-								fParamValue *= 100.0f;
+							if (index == synthv1::DEL1_BPM && fValue < 3.6f)
+								fValue *= 100.0f;
 						#endif
-							float *pfParamPort = pSynth->paramPort(index);
-							if (pfParamPort)
-								*pfParamPort = fParamValue;
+							pSynth->setParamValue(index, fValue);
 						}
 					}
 				}
@@ -257,12 +267,11 @@ void synthv1_param::savePreset ( synthv1 *pSynth, const QString& sFilename )
 	if (pSynth == NULL)
 		return;
 
-	const QString& sPreset
-		= QFileInfo(sFilename).completeBaseName();
+	const QFileInfo fi(sFilename);
 
 	QDomDocument doc(SYNTHV1_TITLE);
 	QDomElement ePreset = doc.createElement("preset");
-	ePreset.setAttribute("name", sPreset);
+	ePreset.setAttribute("name", fi.completeBaseName());
 	ePreset.setAttribute("version", SYNTHV1_VERSION);
 
 	QDomElement eParams = doc.createElement("params");
@@ -271,18 +280,14 @@ void synthv1_param::savePreset ( synthv1 *pSynth, const QString& sFilename )
 		synthv1::ParamIndex index = synthv1::ParamIndex(i);
 		eParam.setAttribute("index", QString::number(i));
 		eParam.setAttribute("name", synthv1_param::paramName(index));
-		const float *pfParamPort = pSynth->paramPort(index);
-		float fParamValue = 0.0f;
-		if (pfParamPort)
-			fParamValue = *pfParamPort;
-		eParam.appendChild(
-			doc.createTextNode(QString::number(fParamValue)));
+		const float fValue = pSynth->paramValue(index);
+		eParam.appendChild(doc.createTextNode(QString::number(fValue)));
 		eParams.appendChild(eParam);
 	}
 	ePreset.appendChild(eParams);
 	doc.appendChild(ePreset);
 
-	QFile file(sFilename);
+	QFile file(fi.filePath());
 	if (file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
 		QTextStream(&file) << doc.toString();
 		file.close();
