@@ -1,7 +1,7 @@
 // synthv1widget.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,9 +24,13 @@
 
 #include "ui_synthv1widget.h"
 
-#include "synthv1widget_config.h"
+#include "synthv1_config.h"
 
-#include "synthv1.h"
+#include "synthv1_ui.h"
+
+
+// forward decls.
+class synthv1_sched_notifier;
 
 
 //-------------------------------------------------------------------------
@@ -82,8 +86,11 @@ protected slots:
 	// Delay BPM change.
 	void bpmSyncChanged();
 
+	// Schedule notification updater.
+	void updateSchedNotify(int stype);
+
 	// Menu actions.
-	void helpUseNativeDialogs(bool bOn);
+	void helpConfigure();
 
 	void helpAbout();
 	void helpAboutQt();
@@ -91,7 +98,7 @@ protected slots:
 protected:
 
 	// Synth engine accessor.
-	virtual synthv1 *instance() const = 0;
+	virtual synthv1_ui *ui_instance() const = 0;
 
 	// Reset swap params A/B group.
 	void resetSwapParams();
@@ -109,6 +116,9 @@ protected:
 	// Update local tied widgets.
 	void updateParamEx(synthv1::ParamIndex index, float fValue);
 
+	// Preset status updater.
+	void updateLoadPreset(const QString& sPreset);
+
 	// Dirty flag (overridable virtual) methods.
 	virtual void updateDirtyPreset(bool bDirtyPreset);
 
@@ -117,7 +127,7 @@ private:
 	// Instance variables.
 	Ui::synthv1widget m_ui;
 
-	synthv1widget_config m_config;
+	synthv1_sched_notifier *m_sched_notifier;
 
 	QHash<synthv1::ParamIndex, synthv1widget_knob *> m_paramKnobs;
 	QHash<synthv1widget_knob *, synthv1::ParamIndex> m_knobParams;
