@@ -1,7 +1,7 @@
 // synthv1widget_config.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,49 +22,67 @@
 #ifndef __synthv1widget_config_h
 #define __synthv1widget_config_h
 
+#include "ui_synthv1widget_config.h"
+
+#include "synthv1_programs.h"
 #include "synthv1_config.h"
 
-#include <QSettings>
-#include <QStringList>
 
+//----------------------------------------------------------------------------
+// synthv1widget_config -- UI wrapper form.
 
-//-------------------------------------------------------------------------
-// synthv1widget_config - Prototype settings class (singleton).
-//
-
-class synthv1widget_config : public QSettings
+class synthv1widget_config : public QDialog
 {
+	Q_OBJECT
+
 public:
 
-	// Constructor.
-	synthv1widget_config();
+	// ctor.
+	synthv1widget_config(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
 
-	// Default destructor.
+	// dtor.
 	~synthv1widget_config();
 
-	// Default options...
-	QString sPreset;
-	QString sPresetDir;
+	// programs accessors.
+	void setPrograms(synthv1_programs *pPrograms);
+	synthv1_programs *programs() const;
 
-	// Special persistent options.
-	bool bUseNativeDialogs;
+protected slots:
 
-	// Run-time special non-persistent options.
-	bool bDontUseNativeDialogs;
+	// command slots.
+	void programsAddBankItem();
+	void programsAddItem();
+	void programsEditItem();
+	void programsDeleteItem();
 
-	// Singleton instance accessor.
-	static synthv1widget_config *getInstance();
+	// janitor slots.
+	void programsCurrentChanged();
+	void programsActivated();
+	void programsContextMenuRequested(const QPoint&);
+
+	void programsChanged();
+	void optionsChanged();
+
+	// dialog slots.
+	void accept();
+	void reject();
 
 protected:
 
-	// Explicit I/O methods.
-	void load();
-	void save();
+	// stabilizer.
+	void stabilize();
 
 private:
 
-	// The singleton instance.
-	static synthv1widget_config *g_pSettings;
+	// UI struct.
+	Ui::synthv1widget_config m_ui;
+
+	// Programs database.
+	synthv1_programs *m_pPrograms;
+
+	// Dialog dirty flag.
+	int m_iDirtyPrograms;
+	int m_iDirtyOptions;
 };
 
 
