@@ -1,7 +1,7 @@
 // synthv1widget_jack.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -32,6 +32,22 @@
 
 #include <QCloseEvent>
 
+#include <QStyleFactory>
+
+#ifndef CONFIG_LIBDIR
+#if defined(__x86_64__)
+#define CONFIG_LIBDIR CONFIG_PREFIX "/lib64"
+#else
+#define CONFIG_LIBDIR CONFIG_PREFIX "/lib"
+#endif
+#endif
+
+#if QT_VERSION < 0x050000
+#define CONFIG_PLUGINSDIR CONFIG_LIBDIR "/qt4/plugins"
+#else
+#define CONFIG_PLUGINSDIR CONFIG_LIBDIR "/qt5/plugins"
+#endif
+
 
 //-------------------------------------------------------------------------
 // synthv1widget_jack - impl.
@@ -44,16 +60,35 @@ synthv1widget_jack::synthv1widget_jack ( synthv1_jack *pSynth )
 		, m_pNsmClient(NULL)
 	#endif
 {
+	// Special style paths...
+	if (QDir(CONFIG_PLUGINSDIR).exists())
+		QApplication::addLibraryPath(CONFIG_PLUGINSDIR);
+
+	// Custom style theme...
+	synthv1_config *pConfig = synthv1_config::getInstance();
+	if (pConfig && !pConfig->sCustomStyleTheme.isEmpty())
+		QApplication::setStyle(QStyleFactory::create(pConfig->sCustomStyleTheme));
+
+	// Initialize (user) interface stuff...
+	m_pSynthUi = new synthv1_ui(m_pSynth);
+
 	// Initialize preset stuff...
 	// initPreset();
 	updateParamValues();
 }
 
 
-// Synth engine accessor.
-synthv1 *synthv1widget_jack::instance (void) const
+// Destructor.
+synthv1widget_jack::~synthv1widget_jack (void)
 {
-	return m_pSynth;
+	delete m_pSynthUi;
+}
+
+
+// Synth engine accessor.
+synthv1_ui *synthv1widget_jack::ui_instance (void) const
+{
+	return m_pSynthUi;
 }
 
 #ifdef CONFIG_NSM
@@ -63,7 +98,7 @@ void synthv1widget_jack::setNsmClient ( synthv1_nsm *pNsmClient )
 {
 	m_pNsmClient = pNsmClient;
 
-	synthv1widget_config *pConfig = synthv1widget_config::getInstance();
+	synthv1_config *pConfig = synthv1_config::getInstance();
 	if (pConfig)
 		pConfig->bDontUseNativeDialogs = true;
 }
@@ -80,9 +115,7 @@ synthv1_nsm *synthv1widget_jack::nsmClient (void) const
 void synthv1widget_jack::updateParam (
 	synthv1::ParamIndex index, float fValue ) const
 {
-	float *pParamPort = m_pSynth->paramPort(index);
-	if (pParamPort)
-		*pParamPort = fValue;
+	m_pSynthUi->setParamValue(index, fValue);
 }
 
 
